@@ -15,12 +15,12 @@ Carp::Assert::More - convenience wrappers around Carp::Assert
 
 =head1 VERSION
 
-Version 1.22
+Version 1.24
 
 =cut
 
 BEGIN {
-    $VERSION = '1.22';
+    $VERSION = '1.24';
     @ISA = qw(Exporter);
     @EXPORT = qw(
         assert_all_keys_in
@@ -693,7 +693,9 @@ Asserts that C<$date> is a DateTime object.
 
 sub assert_datetime($;$) {
     my $datetime = shift;
-    my $desc     = shift // 'Must be a DateTime object';
+    my $desc     = shift;
+
+    $desc = 'Must be a DateTime object' unless defined($desc);
 
     assert_isa( $datetime, 'DateTime', $desc );
 
